# rankpy
Various ranking and segmentation algorithms for lists of rankings.

## Package organization

### data
Sample .csv files representing survey data & input into the rankpy code.

### environments
YAML file with the necessary Python packages for all code execution.

### notebooks
Jupyter notebooks to show execution of the rankpy code.

### rankpy

`process_example.py` -- Function to convert raw survey data into the required input.<br>
`rank.py` -- Functions to apply Hodge ranking & validation testing.

#### tests
Unit tests for specific functions.
